@@ -12,18 +12,18 @@ use crate::types::{Chunk, Encryption};
 use bincode::serialize;
 use bytes::Bytes;
 use rayon::prelude::*;
-use self_encryption::{EncryptedChunk, SecretKey as BlobSecretKey};
+use self_encryption::{DataMap, EncryptedChunk};
 use serde::{Deserialize, Serialize};
 use std::path::Path;
 
 #[derive(Serialize, Deserialize)]
-pub(crate) enum SecretKey {
-    // Holds the secret key to the source data.
-    FirstLevel(BlobSecretKey),
-    // Holds the secret of an _additional_ level of chunks
-    // resulting from chunking up a previous level secret key.
-    // This happens when that previous level secret key was too big to fit in a chunk itself.
-    AdditionalLevel(BlobSecretKey),
+pub(crate) enum DataMapLevel {
+    // Holds the data map to the source data.
+    First(DataMap),
+    // Holds the data map of an _additional_ level of chunks
+    // resulting from chunking up a previous level data map.
+    // This happens when that previous level data map was too big to fit in a chunk itself.
+    Additional(DataMap),
 }
 
 #[allow(unused)]
@@ -31,24 +31,24 @@ pub(crate) fn encrypt_from_path(
     path: &Path,
     encryption: Option<&impl Encryption>,
 ) -> Result<(BlobAddress, Vec<Chunk>)> {
-    let (secret_key, encrypted_chunks) = encrypt_file(path)?;
-    pack(secret_key, encrypted_chunks, encryption)
+    let (data_map, encrypted_chunks) = encrypt_file(path)?;
+    pack(data_map, encrypted_chunks, encryption)
 }
 
 pub(crate) fn encrypt_blob(
     data: Bytes,
     encryption: Option<&impl Encryption>,
 ) -> Result<(BlobAddress, Vec<Chunk>)> {
-    let (secret_key, encrypted_chunks) = encrypt_data(data)?;
-    pack(secret_key, encrypted_chunks, encryption)
+    let (data_map, encrypted_chunks) = encrypt_data(data)?;
+    pack(data_map, encrypted_chunks, encryption)
 }
 
 /// Returns the top-most chunk address through which the entire
 /// data tree can be accessed, and all the other encrypted chunks.
 /// If encryption is provided, the additional secret key level chunks are encrypted with it.
-/// This is necessary if the data is meant to be private, since a `BlobSecretKey` is used to find and decrypt the original file.
+/// This is necessary if the data is meant to be private, since a `DataMap` is used to find and decrypt the original file.
 pub(crate) fn pack(
-    secret_key: BlobSecretKey,
+    data_map: DataMap,
     encrypted_chunks: Vec<EncryptedChunk>,
     encryption: Option<&impl Encryption>,
 ) -> Result<(BlobAddress, Vec<Chunk>)> {
@@ -59,7 +59,7 @@ pub(crate) fn pack(
     // self encrypted into additional chunks, and now we have a new secret key
     // which points to all of those additional chunks.. and so on.
     let mut chunks = vec![];
-    let mut chunk_content = pack_secret_key(SecretKey::FirstLevel(secret_key), encryption)?;
+    let mut chunk_content = pack_data_map(DataMapLevel::First(data_map), encryption)?;
 
     let (address, additional_chunks) = loop {
         let chunk = to_chunk(chunk_content, encryption)?;
@@ -77,7 +77,7 @@ pub(crate) fn pack(
             break (address, chunks);
         } else {
             let serialized_chunk = Bytes::from(serialize(&chunk)?);
-            let (secret_key, next_encrypted_chunks) =
+            let (data_map, next_encrypted_chunks) =
                 self_encryption::encrypt(serialized_chunk).map_err(Error::SelfEncryption)?;
             chunks = next_encrypted_chunks
                 .par_iter()
@@ -85,7 +85,7 @@ pub(crate) fn pack(
                 .flatten()
                 .chain(chunks)
                 .collect();
-            chunk_content = pack_secret_key(SecretKey::AdditionalLevel(secret_key), encryption)?;
+            chunk_content = pack_data_map(DataMapLevel::Additional(data_map), encryption)?;
         }
     };
 
@@ -104,7 +104,7 @@ pub(crate) fn to_chunk(
     encryption: Option<&impl Encryption>,
 ) -> Result<Chunk> {
     let chunk: Chunk = if let Some(encryption) = encryption {
-        // If this is a SecretKey: strictly, we do not need to encrypt this if it's not going to be the
+        // If this is a DataMapLevel: strictly, we do not need to encrypt this if it's not going to be the
         // last level, since it will then instead be self-encrypted.
         // But we can just as well do it, for now.. (which also lets us avoid some edge case handling).
         let encrypted_content = encryption.encrypt(chunk_content)?;
@@ -116,8 +116,8 @@ pub(crate) fn to_chunk(
     Ok(chunk)
 }
 
-fn pack_secret_key(secret_key: SecretKey, encryption: Option<&impl Encryption>) -> Result<Bytes> {
-    let raw_bytes = Bytes::from(serialize(&secret_key)?);
+fn pack_data_map(data_map: DataMapLevel, encryption: Option<&impl Encryption>) -> Result<Bytes> {
+    let raw_bytes = Bytes::from(serialize(&data_map)?);
     if let Some(encryption) = encryption {
         // strictly, we do not need to encrypt this if it's not going to be the
         // last level, since it will then instead be self-encrypted.
@@ -128,11 +128,11 @@ fn pack_secret_key(secret_key: SecretKey, encryption: Option<&impl Encryption>)
     }
 }
 
-fn encrypt_file(file: &Path) -> Result<(BlobSecretKey, Vec<EncryptedChunk>)> {
+fn encrypt_file(file: &Path) -> Result<(DataMap, Vec<EncryptedChunk>)> {
     let bytes = Bytes::from(std::fs::read(file).map_err(Error::IoError)?);
     self_encryption::encrypt(bytes).map_err(Error::SelfEncryption)
 }
 
-fn encrypt_data(bytes: Bytes) -> Result<(BlobSecretKey, Vec<EncryptedChunk>)> {
+fn encrypt_data(bytes: Bytes) -> Result<(DataMap, Vec<EncryptedChunk>)> {
     self_encryption::encrypt(bytes).map_err(Error::SelfEncryption)
 }
