@@ -27,21 +27,45 @@ impl Client {
         let serialised_query = WireMsg::serialize_msg_payload(&msg)?;
         let signature = self.keypair.sign(&serialised_query);
 
-        retry(|| async {
-            tokio::time::timeout(
-                self.query_timeout,
-                self.send_signed_query(
-                    query.clone(),
-                    client_pk,
-                    serialised_query.clone(),
-                    signature.clone(),
-                ),
-            )
-            .await
-            .map_err(backoff::Error::Transient)
-        })
+        // we divide the total query timeout by this to get a more reasonable starting timeout
+        // this also represents the max retries possible _if no backoff were present_, while still staying within the max_timeout
+        // in practice it's _probably_ one less than this value
+        let max_retry_count = 11.0;
+
+        let starting_query_timeout = self.query_timeout.div_f32(max_retry_count);
+        trace!(
+            "Setting up query retry, initial interval is: {:?}",
+            starting_query_timeout
+        );
+        retry(
+            || async {
+                debug!(
+                    "Attempting {:?} with a query timeout of {:?}",
+                    query, starting_query_timeout
+                );
+                let res = tokio::time::timeout(
+                    // The max timeout is total_timeout / retry_factor, so we should get at least lowest_bound_count retries within the total time (if needed)
+                    starting_query_timeout,
+                    self.send_signed_query(
+                        query.clone(),
+                        client_pk,
+                        serialised_query.clone(),
+                        signature.clone(),
+                    ),
+                )
+                .await;
+
+                debug!("Query {:?} result (w/ timeout) was: {:?}", query, res);
+                res.map_err(backoff::Error::Transient)
+            },
+            starting_query_timeout,
+            self.query_timeout,
+        )
         .await
-        .map_err(|_| Error::NoResponse)?
+        .map_err(|_| {
+            debug!("retries all failed for {:?}, returning no response", query);
+            Error::NoResponse
+        })?
     }
 
     /// Send a Query to the network and await a response
