@@ -194,7 +194,7 @@ impl Core {
 
         let query_response = QueryResponse::GetChunk(response);
 
-        match query_response.operation_id() {
+        let pending_removed = match query_response.operation_id() {
             Ok(op_id) => {
                 let node_id = XorName::from(sending_nodes_pk);
                 self.liveness
@@ -202,9 +202,10 @@ impl Core {
                     .await
             }
             Err(error) => {
-                warn!("Node problems noted when retrieving data: {:?}", error)
+                warn!("Node problems noted when retrieving data: {:?}", error);
+                false
             }
-        }
+        };
 
         // Check for unresponsive adults here.
         for (name, count) in self.liveness.find_unresponsive_nodes().await {
@@ -215,6 +216,11 @@ impl Core {
             commands.push(Command::ProposeOffline(name));
         }
 
+        if !pending_removed {
+            trace!("Ignoring un-expected response");
+            return Ok(commands);
+        }
+
         // Send response if one is warrented
         if query_response.failed_with_data_not_found()
             || (!query_response.is_success()
